@@ -234,13 +234,18 @@ def custom_metrics_summary(name, value, count=1, host_tag=False, service_name=No
 
     :param name:str the name of the metrics, a part of the "metric key"
     :param value:float a value to be recorded associated with this "metric key"
-    :param count:int (optional) count of metrics being reported, default is 1
-    :param host_tag:boolean (optional) default is False, whether host information should be included
+    :param count:int (optional) count of metrics being reported, must be a positive integer, default is 1
+    :param host_tag:boolean (optional) whether host information should be included, default is False
     :param service_name:str (optional) not yet supported, default is None
     :param tags: (optional) appoptics_apm.MetricTags which holds key/value pairs that describe
            the metric and a part of the "metric key", see example below
     :param tags_count: (optional) if tags is given, this must be set to the count of items in tags
-    :return: None
+    :return: integer between 0 and 5 corresponding to 0: OBOE_CUSTOM_METRICS_OK
+                                                      1: OBOE_CUSTOM_METRICS_INVALID_COUNT
+                                                      2: OBOE_CUSTOM_METRICS_INVALID_REPORTER
+                                                      3: OBOE_CUSTOM_METRICS_TAG_LIMIT_EXCEEDED
+                                                      4: OBOE_CUSTOM_METRICS_STOPPING
+                                                      5: OBOE_CUSTOM_METRICS_QUEUE_LIMIT_EXCEEDED
 
     :example::
         # create a MetricTags object for two tags
@@ -256,7 +261,7 @@ def custom_metrics_summary(name, value, count=1, host_tag=False, service_name=No
     if tags is None:
         tags = MetricTags(0)
         tags_count = 0
-    CustomMetrics.summary(name, value, count, host_tag, None, tags, tags_count)
+    return CustomMetrics.summary(name, value, count, host_tag, None, tags, tags_count)
 
 
 def custom_metrics_increment(name, count, host_tag=False, service_name=None, tags=None, tags_count=0):
@@ -264,13 +269,18 @@ def custom_metrics_increment(name, count, host_tag=False, service_name=None, tag
     Creates a new or adds to an existing Increment Metric.
 
     :param name:str the name of the metrics, a part of the "metric key"
-    :param count:int increment value, typically 1
-    :param host_tag:boolean (optional) default is False, whether host information should be included
+    :param count:int increment value, must be a positive integer, typically 1
+    :param host_tag:boolean (optional) whether host information should be included, default is False
     :param service_name:str (optional) not yet supported, default is None
     :param tags: (optional) appoptics_apm.MetricTags which holds key/value pairs that describe
            the metric and a part of the "metric key", see example below
     :param tags_count: (optional) if tags is given, this must be set to the count of items in tags
-    :return: None
+    :return: integer between 0 and 5 corresponding to 0: OBOE_CUSTOM_METRICS_OK
+                                                      1: OBOE_CUSTOM_METRICS_INVALID_COUNT
+                                                      2: OBOE_CUSTOM_METRICS_INVALID_REPORTER
+                                                      3: OBOE_CUSTOM_METRICS_TAG_LIMIT_EXCEEDED
+                                                      4: OBOE_CUSTOM_METRICS_STOPPING
+                                                      5: OBOE_CUSTOM_METRICS_QUEUE_LIMIT_EXCEEDED
 
     :example::
         # create a MetricTags object for two tags
@@ -285,7 +295,7 @@ def custom_metrics_increment(name, count, host_tag=False, service_name=None, tag
     if tags is None:
         tags = MetricTags(0)
         tags_count = 0
-    CustomMetrics.increment(name, count, host_tag, None, tags, tags_count)
+    return CustomMetrics.increment(name, count, host_tag, None, tags, tags_count)
 
 
 _ready = False
@@ -338,7 +348,7 @@ class AppOpticsApmConfig(object):
             'hostname_alias': '',
             'trustedpath': '',
             'events_flush_interval': -1,
-            'events_flush_batch_size': -1,
+            'max_request_size_bytes': -1,
             'ec2_metadata_timeout': 1000,
             'max_flush_wait_time': -1,
             'max_transactions': -1,
@@ -352,6 +362,7 @@ class AppOpticsApmConfig(object):
             'enable_sanitize_sql': True,
             'inst_enabled': defaultdict(lambda: True),
             'log_trace_id': 'never',
+            'proxy': '',
             'transaction': defaultdict(lambda: True),
             'inst': defaultdict(lambda: True)
         }
@@ -418,6 +429,10 @@ class AppOpticsApmConfig(object):
                 if timeout not in range(0, 3001):
                     raise ValueError
                 self._config[key] = timeout
+            elif keys == ['proxy']:
+                if not isinstance(val, six.string_types) or not val.startswith('http://'):
+                    raise ValueError
+                self._config[key] = val
             elif keys == ['tracing_mode']:
                 if not isinstance(val, six.string_types) or val.lower() not in ['always', 'never']:
                     raise ValueError
@@ -1598,7 +1613,7 @@ def _reporter():
             max_transactions=config.get('max_transactions'),
             max_flush_wait_time=config.get('max_flush_wait_time'),
             events_flush_interval=config.get('events_flush_interval'),
-            events_flush_batch_size=config.get('events_flush_batch_size'),
+            max_request_size_bytes=config.get('max_request_size_bytes'),
             reporter=config.get('reporter'),
             host=config.get('collector'),
             service_key=config.get('service_key'),
@@ -1609,7 +1624,9 @@ def _reporter():
             token_bucket_capacity=config.get('token_bucket_capacity'),
             token_bucket_rate=config.get('token_bucket_rate'),
             file_single=config.get('reporter_file_single'),
-            ec2_metadata_timeout=config.get('ec2_metadata_timeout'))
+            ec2_metadata_timeout=config.get('ec2_metadata_timeout'),
+            proxy=config.get('proxy'),
+        )
 
     return reporter_instance
 
@@ -1618,7 +1635,7 @@ def _Event_addInfo_safe(func):
     def wrapped(*args, **kw):
         try:  # call SWIG-generated Event.addInfo (from swig/oboe.py)
             return func(*args, **kw)
-        except NotImplementedError:  # unrecognized type passed to addInfo SWIG binding
+        except TypeError:  # unrecognized type passed to addInfo SWIG binding
             # args: [self, KeyName, Value]
             # 1. for python3, bytes type is not instance of six.string_types, but
             # it causes exception
